@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,14 +21,19 @@ import java.math.BigDecimal;
 
 /**
  * This class is a wrapper around java.math.BigDecimal for percents.
- * 
- * 
+ *
+ *
  */
 public class KualiPercent extends KualiDecimal {
+    private static final long serialVersionUID = 1L;
+
+    public static final KualiPercent ZERO = new KualiPercent(BigDecimal.ZERO);
+
+    protected static final KualiPercent ONE_HUNDRED = new KualiPercent("100.00");
 
     /**
      * Constructs a KualiPercent.java.
-     * 
+     *
      * @param d
      */
     public KualiPercent(double d) {
@@ -40,12 +45,14 @@ public class KualiPercent extends KualiDecimal {
         super(d);
     }
 
+    public KualiPercent(String d) {
+        super(d);
+    }
+
     /**
      * @return the percent as a decimal
      */
     public KualiDecimal toKualiDecimal() {
-        return this.divide(new KualiDecimal("100"));
+        return divide(ONE_HUNDRED);
     }
-
-
 }
