@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,6 +18,8 @@ package org.kuali.rice.core.impl.datetime;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.time.DurationFormatUtils;
 import org.joda.time.DateTime;
+import org.joda.time.Days;
+import org.joda.time.LocalDate;
 import org.kuali.rice.core.api.datetime.DateTimeService;
 import org.kuali.rice.core.api.CoreConstants;
 import org.kuali.rice.core.api.config.property.ConfigContext;
@@ -227,33 +229,12 @@ public class DateTimeServiceImpl implements DateTimeService, InitializingBean {
 	}
 
 	public int dateDiff(Date startDate, Date endDate, boolean inclusive) {
-		Calendar startDateCalendar = Calendar.getInstance();
-		startDateCalendar.setTime(startDate);
-
-		Calendar endDateCalendar = Calendar.getInstance();
-		endDateCalendar.setTime(endDate);
-
-		int startDateOffset = -(startDateCalendar.get(Calendar.ZONE_OFFSET) + startDateCalendar
-				.get(Calendar.DST_OFFSET))
-				/ (60 * 1000);
-
-		int endDateOffset = -(endDateCalendar.get(Calendar.ZONE_OFFSET) + endDateCalendar
-				.get(Calendar.DST_OFFSET))
-				/ (60 * 1000);
-
-		if (startDateOffset > endDateOffset) {
-			startDateCalendar.add(Calendar.MINUTE, endDateOffset
-					- startDateOffset);
-		}
+		int dateDiff = Days.daysBetween(new LocalDate(startDate), new LocalDate(endDate)).getDays();
 
 		if (inclusive) {
-			startDateCalendar.add(Calendar.DATE, -1);
+			dateDiff += dateDiff >= 0 ? 1 : -1;
 		}
 
-		int dateDiff = Integer.parseInt(DurationFormatUtils.formatDuration(
-				endDateCalendar.getTimeInMillis()
-						- startDateCalendar.getTimeInMillis(), "d", true));
-
 		return dateDiff;
 	}
 
