@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,9 +17,10 @@ package org.kuali.rice.kns.datadictionary.control;
 
 
 /**
-                        The radio element will render an HTML radio control.
-                        The valuesFinderClass will have a getKeyValues() method
-                        that returns a list of KeyValue objects.
+ * The radio element will render an HTML radio control.  The valuesFinderClass will have a getKeyValues() method that
+ * returns a list of KeyValue objects.
+ *
+ * @deprecated Use {@link org.kuali.rice.krad.uif.control.RadioGroupControl}.
  */
 @Deprecated
 public class RadioControlDefinition extends MultivalueControlDefinitionBase {
