@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,6 +15,9 @@
  */
 package org.kuali.rice.krad.datadictionary.parse;
 
+import com.sun.org.apache.xml.internal.serialize.Method;
+import com.sun.org.apache.xml.internal.serialize.OutputFormat;
+import com.sun.org.apache.xml.internal.serialize.XMLSerializer;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -33,9 +36,13 @@ import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.NamedNodeMap;
 import org.w3c.dom.Node;
+import org.w3c.dom.NodeList;
 
+import java.io.IOException;
+import java.io.StringWriter;
 import java.util.ArrayList;
 import java.util.Map;
+import java.util.Set;
 
 /**
  * Parser for parsing xml bean's created using the custom schema into normal spring bean format.
@@ -45,34 +52,26 @@ import java.util.Map;
 public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
     private static final Log LOG = LogFactory.getLog(CustomSchemaParser.class);
 
+    private static final String INC_TAG = "inc";
+
     private static int beanNumber = 0;
 
     /**
      * Retrieves the class of the bean defined by the xml element.
      *
-     * @param bean - The xml element for the bean being parsed.
-     * @return The class associated with the provided tag
+     * @param bean the xml element for the bean being parsed
+     * @return the class associated with the provided tag
      */
-    protected Class getBeanClass(Element bean) {
-        Map<String, BeanTagInfo> beanType = null;
+    @Override
+    protected Class<?> getBeanClass(Element bean) {
+        Map<String, BeanTagInfo> beanType = CustomTagAnnotations.getBeanTags();
 
-        // Attempt to load the list of tags
-        try {
-            beanType = CustomTagAnnotations.getBeanTags();
-        } catch (Exception e) {
-            LOG.error("Error retrieving bean tag information", e);
+        if (!beanType.containsKey(bean.getLocalName())) {
+            return null;
         }
 
-        Class<?> beanTag = null;
-        try {
-            // Retrieve the connected class in the tag map using the xml tag's name.
-
-            beanTag = beanType.get(bean.getLocalName()).getBeanClass();
-        } catch (Exception e) {
-            LOG.error("Error in retrieved bean tag information", e);
-        }
-
-        return beanTag;
+        // retrieve the connected class in the tag map using the xml tag's name.
+        return beanType.get(bean.getLocalName()).getBeanClass();
     }
 
     /**
@@ -95,9 +94,29 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
             LOG.error("Bean Tag not found " + element.getLocalName());
         }
 
+        if (element.getTagName().equals(INC_TAG)) {
+            String parentId = element.getAttribute("compId");
+            bean.setParentName(parentId);
+
+            return;
+        }
+
+        if (element.getTagName().equals("content")) {
+            bean.setParentName("Uif-Content");
+
+            String markup = nodesToString(element.getChildNodes());
+            bean.addPropertyValue("markup", markup);
+
+            return;
+        }
+
         // Retrieve the information for the new bean tag and fill in the default parent if needed
         BeanTagInfo tagInfo = CustomTagAnnotations.getBeanTags().get(element.getLocalName());
-        if (tagInfo.getParent().compareTo("none") != 0) {
+
+        String elementParent = element.getAttribute("parent");
+        if (StringUtils.isNotBlank(elementParent) && !StringUtils.equals(elementParent, tagInfo.getParent())) {
+            bean.setParentName(elementParent);
+        } else if (StringUtils.isNotBlank(tagInfo.getParent())) {
             bean.setParentName(tagInfo.getParent());
         }
 
@@ -114,31 +133,73 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
             String tag = children.get(i).getLocalName();
             BeanTagAttributeInfo info = entries.get(tag);
 
-            String propertyName;
-            BeanTagAttribute.AttributeType type;
-
-            if(children.get(i).getTagName().equals("spring:property")){
+            if (children.get(i).getTagName().equals("spring:property") || children.get(i).getTagName().equals(
+                    "property")) {
                 BeanDefinitionParserDelegate delegate = parserContext.getDelegate();
                 delegate.parsePropertyElement(children.get(i), bean.getBeanDefinition());
+
                 continue;
             }
 
             // Sets the property name to be used when adding the property value
+            String propertyName;
+            BeanTagAttribute.AttributeType type = null;
             if (info == null) {
-                // If the tag is not in the schema map let spring handle the value by forwarding the tag as the
-                // propertyName
-                propertyName = tag;
-                type = findBeanType(children.get(i));
+                propertyName = CustomTagAnnotations.findPropertyByType(element.getLocalName(), tag);
 
+                if (StringUtils.isNotBlank(propertyName)) {
+                    bean.addPropertyValue(propertyName, parseBean(children.get(i), bean, parserContext));
+
+                    continue;
+                } else {
+                    // If the tag is not in the schema map let spring handle the value by forwarding the tag as the
+                    // propertyName
+                    propertyName = tag;
+                    type = findBeanType(children.get(i));
+                }
             } else {
                 // If the tag is found in the schema map use the connected name stored in the attribute information
-                propertyName = info.getName();
+                propertyName = info.getPropertyName();
                 type = info.getType();
             }
+
             // Process the information stored in the child bean
             ArrayList<Element> grandChildren = (ArrayList<Element>) DomUtils.getChildElements(children.get(i));
 
-            if (type == BeanTagAttribute.AttributeType.SINGLEBEAN) {
+            if (type == BeanTagAttribute.AttributeType.SINGLEVALUE) {
+                String propertyValue = DomUtils.getTextValue(children.get(i));
+                bean.addPropertyValue(propertyName, propertyValue);
+            } else if (type == BeanTagAttribute.AttributeType.ANY) {
+                String propertyValue = nodesToString(children.get(i).getChildNodes());
+                bean.addPropertyValue(propertyName, propertyValue);
+            } else if ((type == BeanTagAttribute.AttributeType.DIRECT) || (type
+                    == BeanTagAttribute.AttributeType.DIRECTORBYTYPE)) {
+                boolean isPropertyTag = false;
+                if ((children.get(i).getAttributes().getLength() == 0) && (grandChildren.size() == 1)) {
+                    String grandChildTag = grandChildren.get(0).getLocalName();
+
+                    Class<?> valueClass = info.getValueType();
+                    if (valueClass.isInterface()) {
+                        try {
+                            valueClass = Class.forName(valueClass.getName() + "Base");
+                        } catch (ClassNotFoundException e) {
+                            throw new RuntimeException("Unable to find impl class for interface", e);
+                        }
+                    }
+
+                    Set<String> validTagNames = CustomTagAnnotations.getBeanTagsByClass(valueClass);
+                    if (validTagNames.contains(grandChildTag)) {
+                        isPropertyTag = true;
+                    }
+                }
+
+                if (isPropertyTag) {
+                    bean.addPropertyValue(propertyName, parseBean(grandChildren.get(0), bean, parserContext));
+                } else {
+                    bean.addPropertyValue(propertyName, parseBean(children.get(i), bean, parserContext));
+                }
+            } else if ((type == BeanTagAttribute.AttributeType.SINGLEBEAN) || (type
+                    == BeanTagAttribute.AttributeType.BYTYPE)) {
                 bean.addPropertyValue(propertyName, parseBean(grandChildren.get(0), bean, parserContext));
             } else if (type == BeanTagAttribute.AttributeType.LISTBEAN) {
                 bean.addPropertyValue(propertyName, parseList(grandChildren, children.get(i), bean, parserContext));
@@ -154,7 +215,6 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
                 bean.addPropertyValue(propertyName, parseSet(grandChildren, children.get(i), bean, parserContext));
             }
         }
-        return;
     }
 
     /**
@@ -165,7 +225,7 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param entries - The property entries for the over all tag.
      * @param bean - The bean definition being created.
      */
-    private void processSingleValue(String name, String value, Map<String, BeanTagAttributeInfo> entries,
+    protected void processSingleValue(String name, String value, Map<String, BeanTagAttributeInfo> entries,
             BeanDefinitionBuilder bean) {
 
         if (name.toLowerCase().compareTo("parent") == 0) {
@@ -175,10 +235,6 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
             // If the attribute is defining the parent as  abstract set it in the bean builder.
             bean.setAbstract(Boolean.valueOf(value));
         } else if (name.toLowerCase().compareTo("id") == 0) {
-            if (value.contains("Demo-CollectionGrouping-Section1")) {
-                System.out.println();
-            }
-
             //nothing - insures that its erased
         } else {
             // If the attribute is not a reserved case find the property name form the connected map and add the new
@@ -206,19 +262,22 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param grandchild - The map entry.
      * @return The object (bean or value) entry key
      */
-    private Object findKey(Element grandchild) {
+    protected Object findKey(Element grandchild, BeanDefinitionBuilder parent, ParserContext parserContext) {
         String key = grandchild.getAttribute("key");
         if (!key.isEmpty()) {
             return key;
-        } else {
-            Element keyTag = DomUtils.getChildElementByTagName(grandchild, "spring:key");
-            if (DomUtils.getChildElements(keyTag).size() == 0) {
+        }
+
+        Element keyTag = DomUtils.getChildElementByTagName(grandchild, "key");
+        if (keyTag != null) {
+            if (DomUtils.getChildElements(keyTag).isEmpty()) {
                 return keyTag.getTextContent();
             } else {
-                return DomUtils.getChildElements(keyTag).get(0);
+                return parseBean(DomUtils.getChildElements(keyTag).get(0), parent, parserContext);
             }
         }
-        //throw new Exception("Cannot find Map's key");
+
+        return null;
     }
 
     /**
@@ -227,19 +286,22 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param grandchild - The map entry.
      * @return The object (bean or value) entry value
      */
-    private Object findValue(Element grandchild) {
+    protected Object findValue(Element grandchild, BeanDefinitionBuilder parent, ParserContext parserContext) {
         String value = grandchild.getAttribute("value");
         if (!value.isEmpty()) {
             return value;
-        } else {
-            Element valueTag = DomUtils.getChildElementByTagName(grandchild, "spring:value");
-            if (DomUtils.getChildElements(valueTag).size() == 0) {
+        }
+
+        Element valueTag = DomUtils.getChildElementByTagName(grandchild, "value");
+        if (valueTag != null) {
+            if (DomUtils.getChildElements(valueTag).isEmpty()) {
                 return valueTag.getTextContent();
             } else {
-                return DomUtils.getChildElements(valueTag).get(0);
+                return parseBean(DomUtils.getChildElements(valueTag).get(0), parent, parserContext);
             }
         }
-        //throw new Exception("Cannot find Map's value");
+
+        return null;
     }
 
     /**
@@ -248,7 +310,7 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param tag - The tag to check.
      * @return The schema attribute type.
      */
-    private BeanTagAttribute.AttributeType findBeanType(Element tag) {
+    protected BeanTagAttribute.AttributeType findBeanType(Element tag) {
         int numberChildren = 0;
 
         // Checks if the user overrides the default attribute type of the schema.
@@ -281,7 +343,7 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
         }
 
         // Checks if the element is a list composed of standard types
-        numberChildren = DomUtils.getChildElementsByTagName(tag, "spring:value").size();
+        numberChildren = DomUtils.getChildElementsByTagName(tag, "value").size();
         if (numberChildren > 0) {
             return BeanTagAttribute.AttributeType.LISTVALUE;
         }
@@ -297,12 +359,12 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
         }
 
         // Checks if the element is a map
-        numberChildren = DomUtils.getChildElementsByTagName(tag, "spring:entry").size();
+        numberChildren = DomUtils.getChildElementsByTagName(tag, "entry").size();
         if (numberChildren > 0) {
             return BeanTagAttribute.AttributeType.MAPVALUE;
         }
 
-        numberChildren = DomUtils.getChildElementsByTagName(tag, "spring:map").size();
+        numberChildren = DomUtils.getChildElementsByTagName(tag, "map").size();
         if (numberChildren > 0) {
             return BeanTagAttribute.AttributeType.MAPBEAN;
         }
@@ -325,8 +387,9 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param parserContext - Provided information and functionality regarding current bean set.
      * @return The parsed bean.
      */
-    private Object parseBean(Element tag, BeanDefinitionBuilder parent, ParserContext parserContext) {
-        if (tag.getNamespaceURI().compareTo("http://www.springframework.org/schema/beans") == 0) {
+    protected Object parseBean(Element tag, BeanDefinitionBuilder parent, ParserContext parserContext) {
+        if (tag.getNamespaceURI().compareTo("http://www.springframework.org/schema/beans") == 0 || tag.getLocalName()
+                .equals("bean")) {
             return parseSpringBean(tag, parserContext);
         } else {
             return parseCustomBean(tag, parent, parserContext);
@@ -339,7 +402,7 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param tag - The Element to be parsed.
      * @return The parsed bean.
      */
-    private Object parseSpringBean(Element tag, ParserContext parserContext) {
+    protected Object parseSpringBean(Element tag, ParserContext parserContext) {
         if (tag.getLocalName().compareTo("ref") == 0) {
             // Create the referenced bean by creating a new bean and setting its parent to the referenced bean
             // then replace grand child with it
@@ -352,18 +415,17 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
         //peel off p: properties an make them actual property nodes - p-namespace does not work properly (unknown cause)
         Document document = tag.getOwnerDocument();
         NamedNodeMap attributes = tag.getAttributes();
-        for(int i = 0; i < attributes.getLength(); i++){
+        for (int i = 0; i < attributes.getLength(); i++) {
             Node attribute = attributes.item(i);
             String name = attribute.getNodeName();
-            if(name.startsWith("p:")){
+            if (name.startsWith("p:")) {
                 Element property = document.createElement("property");
                 property.setAttribute("name", StringUtils.removeStart(name, "p:"));
                 property.setAttribute("value", attribute.getTextContent());
 
-                if(tag.getFirstChild() != null){
+                if (tag.getFirstChild() != null) {
                     tag.insertBefore(property, tag.getFirstChild());
-                }
-                else{
+                } else {
                     tag.appendChild(property);
                 }
             }
@@ -392,25 +454,17 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param parserContext - Provided information and functionality regarding current bean set.
      * @return The parsed bean.
      */
-    private Object parseCustomBean(Element tag, BeanDefinitionBuilder parent, ParserContext parserContext) {
-        BeanDefinitionHolder bean;
-        if (tag.getLocalName().compareTo("ref") == 0) {
-            return new RuntimeBeanReference(tag.getAttribute("bean"));
+    protected Object parseCustomBean(Element tag, BeanDefinitionBuilder parent, ParserContext parserContext) {
+        BeanDefinition beanDefinition = parserContext.getDelegate().parseCustomElement(tag, parent.getBeanDefinition());
 
+        String name = beanDefinition.getParentName() + "$Customchild" + beanNumber;
+        if (tag.getAttribute("id") != null && !StringUtils.isEmpty(tag.getAttribute("id"))) {
+            name = tag.getAttribute("id");
         } else {
-            BeanDefinition beanDefinition = parserContext.getDelegate().parseCustomElement(tag,
-                    parent.getBeanDefinition());
-
-            String name = beanDefinition.getParentName() + "$Customchild" + beanNumber;
-            if (tag.getAttribute("id") != null && !StringUtils.isEmpty(tag.getAttribute("id"))) {
-                name = tag.getAttribute("id");
-            } else {
-                beanNumber++;
-            }
-            bean = new BeanDefinitionHolder(beanDefinition, name);
+            beanNumber++;
         }
 
-        return bean;
+        return new BeanDefinitionHolder(beanDefinition, name);
     }
 
     /**
@@ -422,14 +476,14 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param parserContext - Provided information and functionality regarding current bean set.
      * @return A managedList of the nested content.
      */
-    private ManagedList parseList(ArrayList<Element> grandChildren, Element child, BeanDefinitionBuilder parent,
+    protected ManagedList parseList(ArrayList<Element> grandChildren, Element child, BeanDefinitionBuilder parent,
             ParserContext parserContext) {
         ArrayList<Object> listItems = new ArrayList<Object>();
 
         for (int i = 0; i < grandChildren.size(); i++) {
             Element grandChild = grandChildren.get(i);
 
-            if (grandChild.getTagName().compareTo("spring:value") == 0) {
+            if (grandChild.getTagName().compareTo("value") == 0) {
                 listItems.add(grandChild.getTextContent());
             } else {
                 listItems.add(parseBean(grandChild, parent, parserContext));
@@ -439,12 +493,12 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
         String merge = child.getAttribute("merge");
 
         ManagedList beans = new ManagedList(listItems.size());
+        beans.addAll(listItems);
 
         if (merge != null) {
             beans.setMergeEnabled(Boolean.valueOf(merge));
         }
 
-        beans.addAll(listItems);
         return beans;
     }
 
@@ -457,14 +511,14 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param parserContext - Provided information and functionality regarding current bean set.
      * @return A managedSet of the nested content.
      */
-    private ManagedSet parseSet(ArrayList<Element> grandChildren, Element child, BeanDefinitionBuilder parent,
+    protected ManagedSet parseSet(ArrayList<Element> grandChildren, Element child, BeanDefinitionBuilder parent,
             ParserContext parserContext) {
         ManagedSet setItems = new ManagedSet();
 
         for (int i = 0; i < grandChildren.size(); i++) {
             Element grandChild = grandChildren.get(i);
 
-            if (child.getTagName().compareTo("spring:value") == 0) {
+            if (child.getTagName().compareTo("value") == 0) {
                 setItems.add(grandChild.getTextContent());
             } else {
                 setItems.add(parseBean(grandChild, parent, parserContext));
@@ -488,21 +542,51 @@ public class CustomSchemaParser extends AbstractSingleBeanDefinitionParser {
      * @param parserContext - Provided information and functionality regarding current bean set.
      * @return A managedSet of the nested content.
      */
-    private ManagedMap parseMap(ArrayList<Element> grandChildren, Element child, BeanDefinitionBuilder parent,
+    protected ManagedMap parseMap(ArrayList<Element> grandChildren, Element child, BeanDefinitionBuilder parent,
             ParserContext parserContext) {
         ManagedMap map = new ManagedMap();
+
         String merge = child.getAttribute("merge");
-
-        for (int j = 0; j < grandChildren.size(); j++) {
-            Object key = findKey(grandChildren.get(j));
-            Object value = findValue(grandChildren.get(j));
-            map.put(key, value);
-        }
-
         if (merge != null) {
             map.setMergeEnabled(Boolean.valueOf(merge));
         }
 
+        for (int j = 0; j < grandChildren.size(); j++) {
+            Object key = findKey(grandChildren.get(j), parent, parserContext);
+            Object value = findValue(grandChildren.get(j), parent, parserContext);
+
+            map.put(key, value);
+        }
+
         return map;
     }
+
+    protected String nodesToString(NodeList nodeList) {
+        StringBuffer sb = new StringBuffer();
+
+        for (int i = 0; i < nodeList.getLength(); i++) {
+            Node node = nodeList.item(i);
+
+            sb.append(nodeToString(node));
+        }
+
+        return sb.toString();
+    }
+
+    protected String nodeToString(Node node) {
+        StringWriter stringOut = new StringWriter();
+
+        OutputFormat format = new OutputFormat(Method.XML, null, false);
+        format.setOmitXMLDeclaration(true);
+
+        XMLSerializer serial = new XMLSerializer(stringOut, format);
+
+        try {
+            serial.serialize(node);
+        } catch (IOException e) {
+            throw new RuntimeException(e);
+        }
+
+        return stringOut.toString();
+    }
 }
