@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,6 +15,15 @@
  */
 package org.kuali.rice.krad.rules;
 
+import java.security.GeneralSecurityException;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Properties;
+import java.util.Set;
+
 import org.apache.commons.lang.StringUtils;
 import org.kuali.rice.core.api.CoreApiServiceLocator;
 import org.kuali.rice.core.api.config.property.ConfigurationService;
@@ -27,49 +36,41 @@ import org.kuali.rice.kew.api.WorkflowDocument;
 import org.kuali.rice.kim.api.identity.PersonService;
 import org.kuali.rice.kim.api.role.RoleService;
 import org.kuali.rice.kim.api.services.KimApiServiceLocator;
-import org.kuali.rice.krad.bo.BusinessObject;
-import org.kuali.rice.krad.bo.GlobalBusinessObject;
-import org.kuali.rice.krad.bo.PersistableBusinessObject;
+import org.kuali.rice.krad.bo.PersistableBusinessObjectBaseAdapter;
+import org.kuali.rice.krad.data.DataObjectService;
+import org.kuali.rice.krad.data.KradDataServiceLocator;
 import org.kuali.rice.krad.datadictionary.InactivationBlockingMetadata;
 import org.kuali.rice.krad.datadictionary.validation.ErrorLevel;
 import org.kuali.rice.krad.datadictionary.validation.result.ConstraintValidationResult;
 import org.kuali.rice.krad.datadictionary.validation.result.DictionaryValidationResult;
 import org.kuali.rice.krad.document.Document;
-import org.kuali.rice.krad.maintenance.MaintenanceDocument;
 import org.kuali.rice.krad.exception.ValidationException;
+import org.kuali.rice.krad.maintenance.BulkUpdateMaintainable;
+import org.kuali.rice.krad.maintenance.BulkUpdateMaintenanceDataObject;
 import org.kuali.rice.krad.maintenance.Maintainable;
+import org.kuali.rice.krad.maintenance.MaintenanceDocument;
 import org.kuali.rice.krad.maintenance.MaintenanceDocumentAuthorizer;
+import org.kuali.rice.krad.rules.rule.event.AddCollectionLineEvent;
 import org.kuali.rice.krad.rules.rule.event.ApproveDocumentEvent;
-import org.kuali.rice.krad.service.BusinessObjectService;
 import org.kuali.rice.krad.service.DataDictionaryService;
 import org.kuali.rice.krad.service.DataObjectAuthorizationService;
-import org.kuali.rice.krad.service.DataObjectMetaDataService;
 import org.kuali.rice.krad.service.DictionaryValidationService;
 import org.kuali.rice.krad.service.InactivationBlockingDetectionService;
-import org.kuali.rice.krad.service.KRADServiceLocator;
+import org.kuali.rice.krad.service.InactivationBlockingDisplayService;
 import org.kuali.rice.krad.service.KRADServiceLocatorWeb;
-import org.kuali.rice.krad.service.PersistenceStructureService;
+import org.kuali.rice.krad.service.LegacyDataAdapter;
 import org.kuali.rice.krad.util.ErrorMessage;
 import org.kuali.rice.krad.util.ForeignKeyFieldsPopulationState;
 import org.kuali.rice.krad.util.GlobalVariables;
 import org.kuali.rice.krad.util.KRADConstants;
 import org.kuali.rice.krad.util.KRADPropertyConstants;
-import org.kuali.rice.krad.util.ObjectUtils;
 import org.kuali.rice.krad.util.RouteToCompletionUtil;
 import org.kuali.rice.krad.util.UrlFactory;
 import org.kuali.rice.krad.workflow.service.WorkflowDocumentService;
 import org.springframework.util.AutoPopulatingList;
 
-import java.security.GeneralSecurityException;
-import java.util.ArrayList;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import java.util.Properties;
-import java.util.Set;
-
 /**
- * Contains all of the business rules that are common to all maintenance documents
+ * Contains all of the business rules that are common to all maintenance documents.
  *
  * @author Kuali Rice Team (rice.collab@kuali.org)
  */
@@ -82,28 +83,26 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
     public static final String DOCUMENT_ERROR_PREFIX = "document.";
     public static final String MAINTAINABLE_ERROR_PATH = DOCUMENT_ERROR_PREFIX + "newMaintainableObject";
 
-    private PersistenceStructureService persistenceStructureService;
     private DataDictionaryService ddService;
-    private BusinessObjectService boService;
+    private DataObjectService dataObjectService;
     private DictionaryValidationService dictionaryValidationService;
     private ConfigurationService configService;
     private WorkflowDocumentService workflowDocumentService;
     private PersonService personService;
     private RoleService roleService;
-    private DataObjectMetaDataService dataObjectMetaDataService;
     private DataObjectAuthorizationService dataObjectAuthorizationService;
 
     private Object oldDataObject;
     private Object newDataObject;
-    private Class dataObjectClass;
+    private Class<?> dataObjectClass;
 
-    protected List priorErrorPath;
+    protected List<String> priorErrorPath;
 
     /**
      * Default constructor a MaintenanceDocumentRuleBase.java.
      */
     public MaintenanceDocumentRuleBase() {
-        priorErrorPath = new ArrayList();
+        priorErrorPath = new ArrayList<String>();
     }
 
     /**
@@ -223,7 +222,7 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
      */
     protected boolean isDocumentInactivatingBusinessObject(MaintenanceDocument maintenanceDocument) {
         if (maintenanceDocument.isEdit()) {
-            Class dataObjectClass = maintenanceDocument.getNewMaintainableObject().getDataObjectClass();
+            Class<?> dataObjectClass = maintenanceDocument.getNewMaintainableObject().getDataObjectClass();
             // we can only be inactivating a business object if we're editing it
             if (dataObjectClass != null && MutableInactivatable.class.isAssignableFrom(dataObjectClass)) {
                 MutableInactivatable oldInactivateableBO = (MutableInactivatable) oldDataObject;
@@ -243,7 +242,7 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
      */
     protected boolean processInactivationBlockChecking(MaintenanceDocument maintenanceDocument) {
         if (isDocumentInactivatingBusinessObject(maintenanceDocument)) {
-            Class dataObjectClass = maintenanceDocument.getNewMaintainableObject().getDataObjectClass();
+            Class<?> dataObjectClass = maintenanceDocument.getNewMaintainableObject().getDataObjectClass();
             Set<InactivationBlockingMetadata> inactivationBlockingMetadatas =
                     getDataDictionaryService().getAllInactivationBlockingDefinitions(dataObjectClass);
 
@@ -272,28 +271,24 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
      */
     protected boolean processInactivationBlockChecking(MaintenanceDocument maintenanceDocument,
             InactivationBlockingMetadata inactivationBlockingMetadata) {
-        if (newDataObject instanceof PersistableBusinessObject) {
-            String inactivationBlockingDetectionServiceBeanName =
-                    inactivationBlockingMetadata.getInactivationBlockingDetectionServiceBeanName();
-            if (StringUtils.isBlank(inactivationBlockingDetectionServiceBeanName)) {
-                inactivationBlockingDetectionServiceBeanName =
-                        KRADServiceLocatorWeb.DEFAULT_INACTIVATION_BLOCKING_DETECTION_SERVICE;
-            }
-            InactivationBlockingDetectionService inactivationBlockingDetectionService =
-                    KRADServiceLocatorWeb.getInactivationBlockingDetectionService(
-                            inactivationBlockingDetectionServiceBeanName);
+        String inactivationBlockingDetectionServiceBeanName =
+                inactivationBlockingMetadata.getInactivationBlockingDetectionServiceBeanName();
+        if (StringUtils.isBlank(inactivationBlockingDetectionServiceBeanName)) {
+            inactivationBlockingDetectionServiceBeanName =
+                    KRADServiceLocatorWeb.DEFAULT_INACTIVATION_BLOCKING_DETECTION_SERVICE;
+        }
+        InactivationBlockingDetectionService inactivationBlockingDetectionService =
+                KRADServiceLocatorWeb.getInactivationBlockingDetectionService(
+                        inactivationBlockingDetectionServiceBeanName);
 
-            boolean foundBlockingRecord = inactivationBlockingDetectionService.hasABlockingRecord(
-                    (PersistableBusinessObject) newDataObject, inactivationBlockingMetadata);
+        boolean foundBlockingRecord = inactivationBlockingDetectionService.detectBlockingRecord(
+                newDataObject, inactivationBlockingMetadata);
 
-            if (foundBlockingRecord) {
-                putInactivationBlockingErrorOnPage(maintenanceDocument, inactivationBlockingMetadata);
-            }
-
-            return !foundBlockingRecord;
+        if (foundBlockingRecord) {
+            putInactivationBlockingErrorOnPage(maintenanceDocument, inactivationBlockingMetadata);
         }
 
-        return true;
+        return !foundBlockingRecord;
     }
 
     /**
@@ -305,63 +300,55 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
      */
     protected void putInactivationBlockingErrorOnPage(MaintenanceDocument document,
             InactivationBlockingMetadata inactivationBlockingMetadata) {
-        if (!getPersistenceStructureService().hasPrimaryKeyFieldValues(newDataObject)) {
+        if (!getLegacyDataAdapter().hasPrimaryKeyFieldValues(newDataObject)) {
             throw new RuntimeException("Maintenance document did not have all primary key values filled in.");
         }
-        Properties parameters = new Properties();
-        parameters.put(KRADConstants.BUSINESS_OBJECT_CLASS_ATTRIBUTE,
-                inactivationBlockingMetadata.getBlockedBusinessObjectClass().getName());
-        parameters.put(KRADConstants.DISPATCH_REQUEST_PARAMETER,
-                KRADConstants.METHOD_DISPLAY_ALL_INACTIVATION_BLOCKERS);
 
-        List keys = new ArrayList();
-        if (getPersistenceStructureService().isPersistable(newDataObject.getClass())) {
-            keys = getPersistenceStructureService().listPrimaryKeyFieldNames(newDataObject.getClass());
-        }
+        // Even though we found a blocking record in the passed in InactivationBlockingMetada,
+        // we need to look at all inactivationBlockingMetadata associated dataObjectClass for error display
+        Class boClass = document.getNewMaintainableObject().getDataObjectClass();
+        Set<InactivationBlockingMetadata> inactivationBlockingMetadatas =
+                getDataDictionaryService().getAllInactivationBlockingDefinitions(boClass);
 
-        // build key value url parameters used to retrieve the business object
-        String keyName = null;
-        for (Iterator iter = keys.iterator(); iter.hasNext(); ) {
-            keyName = (String) iter.next();
+        StringBuffer errorMessage = new StringBuffer();
 
-            Object keyValue = null;
-            if (keyName != null) {
-                keyValue = ObjectUtils.getPropertyValue(newDataObject, keyName);
-            }
+        if (inactivationBlockingMetadatas != null ) {
 
-            if (keyValue == null) {
-                keyValue = "";
-            } else if (keyValue instanceof java.sql.Date) { //format the date for passing in url
-                if (Formatter.findFormatter(keyValue.getClass()) != null) {
-                    Formatter formatter = Formatter.getFormatter(keyValue.getClass());
-                    keyValue = (String) formatter.format(keyValue);
+            InactivationBlockingDisplayService inactivationBlockingDisplayService = KRADServiceLocatorWeb
+                    .getInactivationBlockingDisplayService();
+
+            for (InactivationBlockingMetadata blockingMetadata : inactivationBlockingMetadatas) {
+
+                String blockingLabel = getDataDictionaryService().getDataDictionary().getDataObjectEntry(inactivationBlockingMetadata.getBlockingDataObjectClass().getName()).getObjectLabel();
+
+                String relationshipLabel = inactivationBlockingMetadata.getRelationshipLabel();
+                String displayLabel;
+
+                if (StringUtils.isEmpty(relationshipLabel)) {
+
+                    displayLabel = blockingLabel;
+                } else {
+                    displayLabel = blockingLabel + " (" + relationshipLabel + ")";
                 }
-            } else {
-                keyValue = keyValue.toString();
-            }
+                List<String> blockerObjectList = inactivationBlockingDisplayService.displayAllBlockingRecords(newDataObject,
+                        inactivationBlockingMetadata);
 
-            // Encrypt value if it is a secure field
-            if (getDataObjectAuthorizationService().attributeValueNeedsToBeEncryptedOnFormsAndLinks(
-                    inactivationBlockingMetadata.getBlockedBusinessObjectClass(), keyName)) {
-                try {
-                    if(CoreApiServiceLocator.getEncryptionService().isEnabled()) {
-                        keyValue = CoreApiServiceLocator.getEncryptionService().encrypt(keyValue);
+                if (!blockerObjectList.isEmpty()) {
+                    errorMessage.append("<h4>"+blockingLabel+"</h4>");
+                    for(String blockerKey : blockerObjectList) {
+                        errorMessage.append("<li>");
+                        errorMessage.append(blockerKey);
+                        errorMessage.append("</li>");
                     }
-                } catch (GeneralSecurityException e) {
-                    LOG.error("Exception while trying to encrypted value for inquiry framework.", e);
-                    throw new RuntimeException(e);
                 }
+
+                errorMessage.append("<br>");
             }
-
-            parameters.put(keyName, keyValue);
         }
 
-        String blockingUrl = UrlFactory.parameterizeUrl(KRADConstants.DISPLAY_ALL_INACTIVATION_BLOCKERS_ACTION,
-                parameters);
-
         // post an error about the locked document
         GlobalVariables.getMessageMap().putError(KRADConstants.GLOBAL_ERRORS,
-                RiceKeyConstants.ERROR_INACTIVATION_BLOCKED, blockingUrl);
+                RiceKeyConstants.ERROR_INACTIVATION_BLOCKED, false, errorMessage.toString());
     }
 
     /**
@@ -400,6 +387,37 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         return success;
     }
 
+    /**
+     * {@inheritDoc}
+     *
+     * This implementation additionally performs existence and duplicate checks.
+     */
+    @Override
+    public boolean processAddCollectionLine(AddCollectionLineEvent addEvent) {
+        MaintenanceDocument maintenanceDocument = (MaintenanceDocument) addEvent.getDocument();
+        String collectionName = addEvent.getCollectionName();
+        Object addLine = addEvent.getAddLine();
+
+        // setup convenience pointers to the old & new bo
+        setupBaseConvenienceObjects(maintenanceDocument);
+
+        // from here on, it is in a default-success mode, and will add the line unless one of the
+        // business rules stop it.
+        boolean success = true;
+
+        // TODO: Will be covered by KULRICE-7666
+        /*
+        // apply rules that check whether child objects that cannot be hooked up by normal means exist and are active   */
+
+        success &= getDictionaryValidationService().validateDefaultExistenceChecksForNewCollectionItem(
+                maintenanceDocument.getNewMaintainableObject().getDataObject(), addLine, collectionName);
+
+        // apply rules that are specific to the class of the maintenance document (if implemented)
+        success &= processCustomAddCollectionLineBusinessRules(maintenanceDocument, collectionName, addLine);
+
+        return success;
+    }
+
     /**
      * This method is a convenience method to easily add a Document level error (ie, one not tied to a specific field,
      * but
@@ -645,10 +663,8 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
      * @return true if it passes DD validation, false otherwise
      */
     protected boolean dataDictionaryValidate(MaintenanceDocument document) {
-        // default to success if no failures
-        boolean success = true;
         LOG.debug("MaintenanceDocument validation beginning");
-
+        boolean success = true;
         // explicitly put the errorPath that the dictionaryValidationService
         // requires
         GlobalVariables.getMessageMap().addToErrorPath("document.newMaintainableObject");
@@ -674,8 +690,6 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         DictionaryValidationResult dictionaryValidationResult = getDictionaryValidationService().validate(
                 newDataObject);
         if (dictionaryValidationResult.getNumberOfErrors() > 0) {
-            success &= false;
-
             for (ConstraintValidationResult cvr : dictionaryValidationResult) {
                 if (cvr.getStatus() == ErrorLevel.ERROR) {
                     GlobalVariables.getMessageMap().putError(cvr.getAttributePath(), cvr.getErrorKey());
@@ -685,14 +699,14 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
 
         // validate default existence checks
         // TODO: Default existence checks need support for general data objects, see KULRICE-7666
-        //        success &= getDictionaryValidationService().validateDefaultExistenceChecks((BusinessObject) dataObject);
-        //        GlobalVariables.getMessageMap().removeFromErrorPath("dataObject");
+        success &= getDictionaryValidationService().validateDefaultExistenceChecks(dataObject);
+        GlobalVariables.getMessageMap().removeFromErrorPath("dataObject");
 
         // explicitly remove the errorPath we've added
         GlobalVariables.getMessageMap().removeFromErrorPath("document.newMaintainableObject");
 
         LOG.debug("MaintenanceDocument validation ending");
-        return true;
+        return success;
     }
 
     /**
@@ -719,19 +733,19 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         Object oldBo = document.getOldMaintainableObject().getDataObject();
         Object newDataObject = document.getNewMaintainableObject().getDataObject();
 
-        // We dont do primaryKeyChecks on Global Business Object maintenance documents. This is
-        // because it doesnt really make any sense to do so, given the behavior of Globals. When a
-        // Global Document completes, it will update or create a new record for each BO in the list.
+        // We don't do primaryKeyChecks on Bulk Update Data Object maintenance documents. This is
+        // because it doesn't really make any sense to do so, given the behavior of Bulk Update. When a
+        // Bulk Update Document completes, it will update or create a new record for each BO in the list.
         // As a result, there's no problem with having existing BO records in the system, they will
         // simply get updated.
-        if (newDataObject instanceof GlobalBusinessObject) {
+        if (newDataObject instanceof BulkUpdateMaintenanceDataObject) {
             return success;
         }
 
         // fail and complain if the person has changed the primary keys on
         // an EDIT maintenance document.
         if (document.isEdit()) {
-            if (!getDataObjectMetaDataService().equalsByPrimaryKeys(oldBo, newDataObject)) {
+            if (!getLegacyDataAdapter().equalsByPrimaryKeys(oldBo, newDataObject)) {
                 // add a complaint to the errors
                 putDocumentError(KRADConstants.DOCUMENT_ERRORS,
                         RiceKeyConstants.ERROR_DOCUMENT_MAINTENANCE_PRIMARY_KEYS_CHANGED_ON_EDIT,
@@ -745,28 +759,37 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         else if (document.isNew()) {
 
             // TODO: when/if we have standard support for DO retrieval, do this check for DO's
-            if (newDataObject instanceof PersistableBusinessObject) {
+            if (newDataObject instanceof PersistableBusinessObjectBaseAdapter) {
 
                 // get a map of the pk field names and values
-                Map<String, ?> newPkFields = getDataObjectMetaDataService().getPrimaryKeyFieldValues(newDataObject);
+                Map<String, ?> newPkFields = getLegacyDataAdapter().getPrimaryKeyFieldValuesDOMDS(newDataObject);
 
-                // TODO: Good suggestion from Aaron, dont bother checking the DB, if all of the
-                // objects PK fields dont have values. If any are null or empty, then
-                // we're done. The current way wont fail, but it will make a wasteful
-                // DB call that may not be necessary, and we want to minimize these.
+                //Remove any parts of the pk that has a null value as JPA will throw an error
+                Map<String, Object> filteredPkFields = new HashMap<String, Object>();
+                filteredPkFields.putAll(newPkFields);
 
-                // attempt to do a lookup, see if this object already exists by these Primary Keys
-                PersistableBusinessObject testBo = getBoService().findByPrimaryKey(dataObjectClass.asSubclass(
-                        PersistableBusinessObject.class), newPkFields);
-
-                // if the retrieve was successful, then this object already exists, and we need
-                // to complain
-                if (testBo != null) {
-                    putDocumentError(KRADConstants.DOCUMENT_ERRORS,
-                            RiceKeyConstants.ERROR_DOCUMENT_MAINTENANCE_KEYS_ALREADY_EXIST_ON_CREATE_NEW,
-                            getHumanReadablePrimaryKeyFieldNames(dataObjectClass));
-                    success &= false;
+                Iterator it = newPkFields.entrySet().iterator();
+                while (it.hasNext()) {
+                    Map.Entry pairs = (Map.Entry)it.next();
+                    if(pairs.getValue() == null){
+                       filteredPkFields.remove(pairs.getKey());
+                    }
                 }
+
+                if(!filteredPkFields.isEmpty()){
+                    // attempt to do a lookup, see if this object already exists by these Primary Keys
+                    Object testBo = getLegacyDataAdapter().findByPrimaryKey(dataObjectClass, filteredPkFields);
+
+                    // if the retrieve was successful, then this object already exists, and we need
+                    // to complain
+                    if (testBo != null) {
+                        putDocumentError(KRADConstants.DOCUMENT_ERRORS,
+                                RiceKeyConstants.ERROR_DOCUMENT_MAINTENANCE_KEYS_ALREADY_EXIST_ON_CREATE_NEW,
+                                getHumanReadablePrimaryKeyFieldNames(dataObjectClass));
+                        success &= false;
+                    }
+                }
+
             }
         }
 
@@ -778,14 +801,14 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
      * DataDictionary.
      *
      * @param dataObjectClass
-     * @return
+     * @return human-readable string representation of the primary key field names
      */
     protected String getHumanReadablePrimaryKeyFieldNames(Class<?> dataObjectClass) {
         String delim = "";
-        StringBuffer pkFieldNames = new StringBuffer();
+        StringBuilder pkFieldNames = new StringBuilder();
 
         // get a list of all the primary key field names, walk through them
-        List<String> pkFields = getDataObjectMetaDataService().listPrimaryKeyFieldNames(dataObjectClass);
+        List<String> pkFields = getLegacyDataAdapter().listPrimaryKeyFieldNames(dataObjectClass);
         for (Iterator<String> iter = pkFields.iterator(); iter.hasNext(); ) {
             String pkFieldName = (String) iter.next();
 
@@ -900,12 +923,22 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
      * This method should be overridden to provide custom rules for processing document approval.
      *
      * @param document
-     * @return booelan
+     * @return boolean
      */
     protected boolean processCustomApproveDocumentBusinessRules(MaintenanceDocument document) {
         return true;
     }
 
+    /**
+     * This method should be overridden to provide custom rules for processing adding collection lines.
+     *
+     * @param document
+     * @return boolean
+     */
+    protected boolean processCustomAddCollectionLineBusinessRules(MaintenanceDocument document, String collectionName, Object line) {
+        return true;
+    }
+
     // Document Validation Helper Methods
 
     /**
@@ -926,7 +959,7 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         success &= super.isDocumentOverviewValid(maintenanceDocument);
         success &= validateDocumentStructure((Document) maintenanceDocument);
         success &= validateMaintenanceDocument(maintenanceDocument);
-        success &= validateGlobalBusinessObjectPersistable(maintenanceDocument);
+        success &= validateBulkUpdateMaintenanceDocument(maintenanceDocument);
         return success;
     }
 
@@ -954,8 +987,7 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
 
     /**
      * This method checks to make sure the document is a valid maintenanceDocument, and has the necessary values
-     * populated such that
-     * it will not cause exceptions in later routing or business rules testing.
+     * populated such that it will not cause exceptions in later routing or business rules testing.
      *
      * This is not a business rules test.
      *
@@ -983,34 +1015,22 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
     }
 
     /**
-     * This method checks whether this maint doc contains Global Business Objects, and if so, whether the GBOs are in a
-     * persistable
-     * state. This will return false if this method determines that the GBO will cause a SQL Exception when the
-     * document
-     * is
-     * persisted.
+     * This method checks whether this maintenance document represents a bulk update maintenance document, and if so,
+     * whether the data object is in a persistable state.
      *
-     * @param document
-     * @return False when the method determines that the contained Global Business Object will cause a SQL Exception,
-     *         and the
-     *         document should not be saved. It will return True otherwise.
+     * @param maintenanceDocument- document to be tested
+     * @return false for bulk update maintenance doc that are not persistable, true otherwise (incl. non-bulkupdate
+     *         maintenance documents)
      */
-    protected boolean validateGlobalBusinessObjectPersistable(MaintenanceDocument document) {
+    protected boolean validateBulkUpdateMaintenanceDocument(MaintenanceDocument maintenanceDocument) {
         boolean success = true;
+        Maintainable newMaintainable = maintenanceDocument.getNewMaintainableObject();
 
-        if (document.getNewMaintainableObject() == null) {
-            return success;
-        }
-        if (document.getNewMaintainableObject().getDataObject() == null) {
-            return success;
-        }
-        if (!(document.getNewMaintainableObject().getDataObject() instanceof GlobalBusinessObject)) {
-            return success;
+        if (newMaintainable instanceof BulkUpdateMaintainable) {
+            success = ((BulkUpdateMaintainable) newMaintainable).isPersistable();
         }
 
-        PersistableBusinessObject bo = (PersistableBusinessObject) document.getNewMaintainableObject().getDataObject();
-        GlobalBusinessObject gbo = (GlobalBusinessObject) bo;
-        return gbo.isPersistable();
+        return success;
     }
 
     /**
@@ -1139,17 +1159,18 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
     /**
      * @see MaintenanceDocumentRule#setupBaseConvenienceObjects(org.kuali.rice.krad.maintenance.MaintenanceDocument)
      */
+    @Override
     public void setupBaseConvenienceObjects(MaintenanceDocument document) {
         // setup oldAccount convenience objects, make sure all possible sub-objects are populated
         oldDataObject = document.getOldMaintainableObject().getDataObject();
-        if (oldDataObject != null && oldDataObject instanceof PersistableBusinessObject) {
-            ((PersistableBusinessObject) oldDataObject).refreshNonUpdateableReferences();
+        if (oldDataObject != null && oldDataObject instanceof PersistableBusinessObjectBaseAdapter) {
+            ((PersistableBusinessObjectBaseAdapter) oldDataObject).refreshNonUpdateableReferences();
         }
 
         // setup newAccount convenience objects, make sure all possible sub-objects are populated
         newDataObject = document.getNewMaintainableObject().getDataObject();
-        if (newDataObject instanceof PersistableBusinessObject) {
-            ((PersistableBusinessObject) newDataObject).refreshNonUpdateableReferences();
+        if (newDataObject instanceof PersistableBusinessObjectBaseAdapter) {
+            ((PersistableBusinessObjectBaseAdapter) newDataObject).refreshNonUpdateableReferences();
         }
 
         dataObjectClass = document.getNewMaintainableObject().getDataObjectClass();
@@ -1158,6 +1179,7 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         setupConvenienceObjects();
     }
 
+    @Override
     public void setupConvenienceObjects() {
         // should always be overriden by subclass
     }
@@ -1175,34 +1197,30 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
     protected boolean checkForPartiallyFilledOutReferenceForeignKeys(String referenceName) {
         boolean success = true;
 
-        if (newDataObject instanceof PersistableBusinessObject) {
-            ForeignKeyFieldsPopulationState fkFieldsState;
-            fkFieldsState = getPersistenceStructureService().getForeignKeyFieldsPopulationState(
-                    (PersistableBusinessObject) newDataObject, referenceName);
+        ForeignKeyFieldsPopulationState fkFieldsState = getLegacyDataAdapter().getForeignKeyFieldsPopulationState( newDataObject, referenceName);
 
-            // determine result
-            if (fkFieldsState.isAnyFieldsPopulated() && !fkFieldsState.isAllFieldsPopulated()) {
-                success = false;
+        // determine result
+        if (fkFieldsState.isAnyFieldsPopulated() && !fkFieldsState.isAllFieldsPopulated()) {
+            success = false;
 
-                // add errors if appropriate
+            // add errors if appropriate
 
-                // get the full set of foreign-keys
-                List fKeys = new ArrayList(getPersistenceStructureService().getForeignKeysForReference(
-                        newDataObject.getClass().asSubclass(PersistableBusinessObject.class), referenceName).keySet());
-                String fKeysReadable = consolidateFieldNames(fKeys, ", ").toString();
+            // get the full set of foreign-keys
+            List fKeys = new ArrayList(getLegacyDataAdapter().getForeignKeysForReference(
+                    newDataObject.getClass(), referenceName).keySet());
+            String fKeysReadable = consolidateFieldNames(fKeys, ", ").toString();
 
-                // walk through the missing fields
-                for (Iterator iter = fkFieldsState.getUnpopulatedFieldNames().iterator(); iter.hasNext(); ) {
-                    String fieldName = (String) iter.next();
+            // walk through the missing fields
+            for (Iterator iter = fkFieldsState.getUnpopulatedFieldNames().iterator(); iter.hasNext(); ) {
+                String fieldName = (String) iter.next();
 
-                    // get the human-readable name
-                    String fieldNameReadable = getDataDictionaryService().getAttributeLabel(newDataObject.getClass(),
-                            fieldName);
+                // get the human-readable name
+                String fieldNameReadable = getDataDictionaryService().getAttributeLabel(newDataObject.getClass(),
+                        fieldName);
 
-                    // add a field error
-                    putFieldError(fieldName, RiceKeyConstants.ERROR_DOCUMENT_MAINTENANCE_PARTIALLY_FILLED_OUT_REF_FKEYS,
-                            new String[]{fieldNameReadable, fKeysReadable});
-                }
+                // add a field error
+                putFieldError(fieldName, RiceKeyConstants.ERROR_DOCUMENT_MAINTENANCE_PARTIALLY_FILLED_OUT_REF_FKEYS,
+                        new String[]{fieldNameReadable, fKeysReadable});
             }
         }
 
@@ -1215,15 +1233,15 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
      * @param fieldNames - List of fieldNames
      * @return A filled StringBuffer ready to go in an error message
      */
-    protected StringBuffer consolidateFieldNames(List fieldNames, String delimiter) {
-        StringBuffer sb = new StringBuffer();
+    protected StringBuilder consolidateFieldNames(List<String> fieldNames, String delimiter) {
+        StringBuilder sb = new StringBuilder();
 
         // setup some vars
         boolean firstPass = true;
         String delim = "";
 
         // walk through the list
-        for (Iterator iter = fieldNames.iterator(); iter.hasNext(); ) {
+        for (Iterator<String> iter = fieldNames.iterator(); iter.hasNext(); ) {
             String fieldName = (String) iter.next();
 
             // get the human-readable name
@@ -1262,7 +1280,7 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
      * @param fieldName The fieldName you want a human-readable label for.
      * @return A human-readable label, pulled from the DataDictionary.
      */
-    protected String getFieldLabel(Class dataObjectClass, String fieldName) {
+    protected String getFieldLabel(Class<?> dataObjectClass, String fieldName) {
         return getDataDictionaryService().getAttributeLabel(dataObjectClass, fieldName) + "(" +
                 getDataDictionaryService().getAttributeShortLabel(dataObjectClass, fieldName) + ")";
     }
@@ -1289,22 +1307,6 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         return oldDataObject;
     }
 
-    public boolean processCustomAddCollectionLineBusinessRules(MaintenanceDocument document, String collectionName,
-            PersistableBusinessObject line) {
-        return true;
-    }
-
-    protected final BusinessObjectService getBoService() {
-        if (boService == null) {
-            this.boService = KRADServiceLocator.getBusinessObjectService();
-        }
-        return boService;
-    }
-
-    public final void setBoService(BusinessObjectService boService) {
-        this.boService = boService;
-    }
-
     protected final ConfigurationService getConfigService() {
         if (configService == null) {
             this.configService = CoreApiServiceLocator.getKualiConfigurationService();
@@ -1327,6 +1329,7 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         this.ddService = ddService;
     }
 
+    @Override
     protected final DictionaryValidationService getDictionaryValidationService() {
         if (dictionaryValidationService == null) {
             this.dictionaryValidationService = KRADServiceLocatorWeb.getDictionaryValidationService();
@@ -1338,6 +1341,7 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         this.dictionaryValidationService = dictionaryValidationService;
     }
 
+    @Override
     public PersonService getPersonService() {
         if (personService == null) {
             this.personService = KimApiServiceLocator.getPersonService();
@@ -1360,28 +1364,6 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         return this.roleService;
     }
 
-    protected DataObjectMetaDataService getDataObjectMetaDataService() {
-        if (dataObjectMetaDataService == null) {
-            this.dataObjectMetaDataService = KRADServiceLocatorWeb.getDataObjectMetaDataService();
-        }
-        return dataObjectMetaDataService;
-    }
-
-    public void setDataObjectMetaDataService(DataObjectMetaDataService dataObjectMetaDataService) {
-        this.dataObjectMetaDataService = dataObjectMetaDataService;
-    }
-
-    protected final PersistenceStructureService getPersistenceStructureService() {
-        if (persistenceStructureService == null) {
-            this.persistenceStructureService = KRADServiceLocator.getPersistenceStructureService();
-        }
-        return persistenceStructureService;
-    }
-
-    public final void setPersistenceStructureService(PersistenceStructureService persistenceStructureService) {
-        this.persistenceStructureService = persistenceStructureService;
-    }
-
     public WorkflowDocumentService getWorkflowDocumentService() {
         if (workflowDocumentService == null) {
             this.workflowDocumentService = KRADServiceLocatorWeb.getWorkflowDocumentService();
@@ -1404,5 +1386,16 @@ public class MaintenanceDocumentRuleBase extends DocumentRuleBase implements Mai
         this.dataObjectAuthorizationService = dataObjectAuthorizationService;
     }
 
+    private LegacyDataAdapter getLegacyDataAdapter() {
+        return KRADServiceLocatorWeb.getLegacyDataAdapter();
+    }
+
+    public DataObjectService getDataObjectService() {
+        if ( dataObjectService == null ) {
+            dataObjectService = KradDataServiceLocator.getDataObjectService();
+        }
+        return dataObjectService;
+    }
+
 }
 
