@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -33,12 +33,7 @@ import org.kuali.rice.krad.data.provider.Provider;
 import org.kuali.rice.krad.datadictionary.BusinessObjectEntry;
 import org.kuali.rice.krad.datadictionary.PrimitiveAttributeDefinition;
 import org.kuali.rice.krad.datadictionary.RelationshipDefinition;
-import org.kuali.rice.krad.service.BusinessObjectNotLookupableException;
-import org.kuali.rice.krad.service.KRADServiceLocatorWeb;
-import org.kuali.rice.krad.service.KualiModuleService;
-import org.kuali.rice.krad.service.LegacyDataAdapter;
-import org.kuali.rice.krad.service.LookupService;
-import org.kuali.rice.krad.service.ModuleService;
+import org.kuali.rice.krad.service.*;
 import org.kuali.rice.krad.uif.UifParameters;
 import org.kuali.rice.krad.util.ExternalizableBusinessObjectUtils;
 import org.kuali.rice.krad.util.KRADConstants;
@@ -354,7 +349,7 @@ public abstract class RemoteModuleServiceBase implements ModuleService {
         try {
             Class<? extends ExternalizableBusinessObject> propertyType =
                     (Class<? extends ExternalizableBusinessObject>)PropertyUtils.getPropertyType(businessObject,
-                    externalizableRelationshipName);
+                            externalizableRelationshipName);
             clazz = getExternalizableBusinessObjectImplementation(propertyType);
         } catch (Exception iex) {
             LOG.warn("Exception:"
